@@ -1,8 +1,5 @@
 package Child;
 
-use strict;
-use warnings;
-
 use Sibling;
 use Parent;
 
